@@ -21,7 +21,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <assert.h>
-#include <math.h>
+#include <string.h>
 
 #include "frame.h"
 #include "coder.h"
@@ -29,9 +29,7 @@
 #include "channels.h"
 #include "bitstream.h"
 #include "filtbank.h"
-#include "aacquant.h"
 #include "util.h"
-#include "huffman.h"
 #include "tns.h"
 #include "version.h"
 
@@ -54,7 +52,10 @@ static const psymodellist_t psymodellist[] = {
 static SR_INFO srInfo[12+1];
 
 // default bandwidth/samplerate ratio
-static const double bwfac = 0.42;
+static const struct {
+    double fac;
+    double freq;
+} g_bw = {0.42, 18000};
 
 int FAACAPI faacEncGetVersion( char **faac_id_string,
 			      				char **faac_copyright_string)
@@ -156,7 +157,10 @@ int FAACAPI faacEncSetConfiguration(faacEncHandle hpEncoder,
 
     if (config->bitRate && !config->bandWidth)
     {
-        config->bandWidth = (double)config->bitRate * hEncoder->sampleRate * bwfac / 60000.0;
+        config->bandWidth = (double)config->bitRate * hEncoder->sampleRate * g_bw.fac / 50000.0;
+        if (config->bandWidth > g_bw.freq)
+            config->bandWidth = g_bw.freq;
+
         if (!config->quantqual)
         {
             config->quantqual = (double)config->bitRate * hEncoder->numChannels / 1280;
@@ -172,7 +176,7 @@ int FAACAPI faacEncSetConfiguration(faacEncHandle hpEncoder,
 
     if (!config->bandWidth)
     {
-        config->bandWidth = bwfac * hEncoder->sampleRate;
+        config->bandWidth = g_bw.fac * hEncoder->sampleRate;
     }
 
     hEncoder->config.bandWidth = config->bandWidth;
@@ -255,8 +259,8 @@ faacEncHandle FAACAPI faacEncOpen(unsigned long sampleRate,
     hEncoder->config.allowMidside = 1;
     hEncoder->config.useLfe = 1;
     hEncoder->config.useTns = 0;
-    hEncoder->config.bitRate = 0; /* default bitrate / channel */
-    hEncoder->config.bandWidth = bwfac * hEncoder->sampleRate;
+    hEncoder->config.bitRate = 64000;
+    hEncoder->config.bandWidth = g_bw.fac * hEncoder->sampleRate;
     hEncoder->config.quantqual = 0;
     hEncoder->config.psymodellist = (psymodellist_t *)psymodellist;
     hEncoder->config.psymodelidx = 0;
@@ -303,13 +307,6 @@ faacEncHandle FAACAPI faacEncOpen(unsigned long sampleRate,
 
     TnsInit(hEncoder);
 
-    AACQuantizeInit(hEncoder->coderInfo, hEncoder->numChannels,
-		    &(hEncoder->aacquantCfg));
-
-	
-
-    HuffmanInit(hEncoder->coderInfo, hEncoder->numChannels);
-
     /* Return handle */
     return hEncoder;
 }
@@ -324,12 +321,7 @@ int FAACAPI faacEncClose(faacEncHandle hpEncoder)
 
     FilterBankEnd(hEncoder);
 
-    AACQuantizeEnd(hEncoder->coderInfo, hEncoder->numChannels,
-			&(hEncoder->aacquantCfg));
-
-    HuffmanEnd(hEncoder->coderInfo, hEncoder->numChannels);
-
-	fft_terminate( &hEncoder->fft_tables );
+    fft_terminate(&hEncoder->fft_tables);
 
     /* Free remaining buffer memory */
     for (channel = 0; channel < hEncoder->numChannels; channel++) 
@@ -348,6 +340,8 @@ int FAACAPI faacEncClose(faacEncHandle hpEncoder)
     if (hEncoder) 
 		FreeMemory(hEncoder);
 
+    BlocStat();
+
     return 0;
 }
 
@@ -502,7 +496,7 @@ int FAACAPI faacEncEncode(faacEncHandle hpEncoder,
 			coderInfo[channel].block_type = ONLY_LONG_WINDOW;
 		}
     }
-    if (shortctl == SHORTCTL_NOLONG)
+    else if ((hEncoder->frameNum <= 4) || (shortctl == SHORTCTL_NOLONG))
     {
 		for (channel = 0; channel < numChannels; channel++)
 		{
@@ -520,29 +514,19 @@ int FAACAPI faacEncEncode(faacEncHandle hpEncoder,
             MOVERLAPPED);
     }
 
-    /* TMP: Build sfb offset table and other stuff */
     for (channel = 0; channel < numChannels; channel++) {
         channelInfo[channel].msInfo.is_present = 0;
 
         if (coderInfo[channel].block_type == ONLY_SHORT_WINDOW) {
             coderInfo[channel].sfbn = hEncoder->aacquantCfg.max_cbs;
 
-            coderInfo[channel].groups.n = 1;
-            coderInfo[channel].groups.len[0] = 8;
-            coderInfo[channel].groups.len[1] = 0;
-            coderInfo[channel].groups.len[2] = 0;
-            coderInfo[channel].groups.len[3] = 0;
-            coderInfo[channel].groups.len[4] = 0;
-            coderInfo[channel].groups.len[5] = 0;
-            coderInfo[channel].groups.len[6] = 0;
-            coderInfo[channel].groups.len[7] = 0;
-
             offset = 0;
             for (sb = 0; sb < coderInfo[channel].sfbn; sb++) {
                 coderInfo[channel].sfb_offset[sb] = offset;
                 offset += hEncoder->srInfo->cb_width_short[sb];
             }
             coderInfo[channel].sfb_offset[sb] = offset;
+            BlocGroup(hEncoder->freqBuff[channel], coderInfo + channel, hEncoder->aacquantCfg.max_cbs);
         } else {
             coderInfo[channel].sfbn = hEncoder->aacquantCfg.max_cbl;
 
@@ -573,13 +557,6 @@ int FAACAPI faacEncEncode(faacEncHandle hpEncoder,
     }
 
     for (channel = 0; channel < numChannels; channel++) {
-		if (coderInfo[channel].block_type == ONLY_SHORT_WINDOW) {
-			SortForGrouping(&coderInfo[channel],
-					hEncoder->srInfo->cb_width_short,
-					hEncoder->freqBuff[channel]);
-		}
-		CalcAvgEnrg(&coderInfo[channel], hEncoder->freqBuff[channel]);
-
       // reduce LFE bandwidth
 		if (!channelInfo[channel].cpe && channelInfo[channel].lfe)
 		{
@@ -587,12 +564,12 @@ int FAACAPI faacEncEncode(faacEncHandle hpEncoder,
 		}
 	}
 
-    MSEncode(coderInfo, channelInfo, hEncoder->freqBuff, numChannels, allowMidside);
-
-    for (channel = 0; channel < numChannels; channel++)
-    {
-        CalcAvgEnrg(&coderInfo[channel], hEncoder->freqBuff[channel]);
-    }
+    if (allowMidside)
+        MSEncode(coderInfo, channelInfo, hEncoder->freqBuff, numChannels,
+                 (double)hEncoder->aacquantCfg.quality/DEFQUAL);
+    else
+        MSEncode(coderInfo, channelInfo, hEncoder->freqBuff, numChannels,
+                 0.0);
 
 #ifdef DRM
     /* loop the quantization until the desired bit-rate is reached */
@@ -600,19 +577,9 @@ int FAACAPI faacEncEncode(faacEncHandle hpEncoder,
     hEncoder->aacquantCfg.quality = 120; /* init quality setting */
     while (diff > 0) { /* if too many bits, do it again */
 #endif
-    /* Quantize and code the signal */
     for (channel = 0; channel < numChannels; channel++) {
-        if (coderInfo[channel].block_type == ONLY_SHORT_WINDOW) {
-            AACQuantize(&coderInfo[channel],
-                        hEncoder->srInfo->cb_width_short,
-                        hEncoder->srInfo->num_cb_short, hEncoder->freqBuff[channel],
-                        &(hEncoder->aacquantCfg));
-        } else {
-            AACQuantize(&coderInfo[channel],
-                        hEncoder->srInfo->cb_width_long,
-                        hEncoder->srInfo->num_cb_long, hEncoder->freqBuff[channel],
-                        &(hEncoder->aacquantCfg));
-        }
+        BlocQuant(&coderInfo[channel], hEncoder->freqBuff[channel],
+                  &(hEncoder->aacquantCfg));
     }
 
 #ifdef DRM
